@@ -24,7 +24,7 @@ class CustomFieldsListWidget : public QWidget
     Q_OBJECT
 public:
     explicit CustomFieldsListWidget(QWidget *parent = nullptr);
-    ~CustomFieldsListWidget();
+    ~CustomFieldsListWidget() override;
     void storeContact(KContacts::Addressee &contact) const;
     void loadContact(const KContacts::Addressee &contact);
     void setReadOnly(bool readOnly);
